##  REFERENCE_FIELD
This mapping type is used when pulling or pushing to a Reference or Glide List field in ServiceNow that refers to a table in sync. During the synchronization run, the integration will automatically detect the exact technical type behind the field which is selected in the following dropdown and apply the suitable updates.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2746c4907a4410149833c16e59cf46d0_LowRes.png)
